"""
Django settings for daren project.

Generated by 'django-admin startproject' using Django 5.1.5.

For more information on this file, see
https://docs.djangoproject.com/en/5.1/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/5.1/ref/settings/
"""

from pathlib import Path
import os
# Build paths inside the project like this: BASE_DIR / 'subdir'.
BASE_DIR = Path(__file__).resolve().parent.parent

import pymysql
pymysql.install_as_MySQLdb()

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/5.1/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'django-insecure-6#we0eu(p&%ejp^=vmig!43m#+@k5rsb3zv^6%623uk&e#zzgl'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True

ALLOWED_HOSTS = ['*']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django_filters',
    'django.contrib.staticfiles',
    'channels',
    'apps.user.apps.UserConfig',
    "apps.expertproducts.apps.ExpertproductsConfig",
    "apps.daren_detail.apps.DarenDetailConfig",
    "apps.discovery.apps.DiscoveryConfig",
    "apps.template.apps.TemplateConfig",
    "apps.brands.apps.BrandsConfig",
    'rest_framework',
    'rest_framework_simplejwt',
    "apps.chat.apps.ChatConfig",
    "apps.common.apps.CommonConfig",
    "apps.knowledge_base.apps.KnowledgeBaseConfig",
    "apps.gmail.apps.GmailConfig",
    "apps.feishu.apps.FeishuConfig",
    'django_celery_beat',  # Celery定时任务
    'django_celery_results',  # Celery结果存储
    "apps.rlhf.apps.RlhfConfig",
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'daren.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [BASE_DIR / 'templates']
        ,
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'daren.wsgi.application'
ASGI_APPLICATION = 'daren.asgi.application'

# WebSocket配置
CHANNEL_LAYERS = {
    'default': {
        'BACKEND': 'channels.layers.InMemoryChannelLayer',
    },
}


# Database
# https://docs.djangoproject.com/en/5.1/ref/settings/#databases

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.mysql',
        'NAME': 'daren_detail',
        'USER': 'root',
        'PASSWORD': '123456',
        'HOST': '192.168.31.138',
        'PORT': '3306',
        'OPTIONS': {
            'charset': 'utf8mb4',
            'init_command': "SET sql_mode='STRICT_TRANS_TABLES'",
            'connect_timeout': 60,
        },
        'CONN_MAX_AGE': 0,
    }
}


# Password validation
# https://docs.djangoproject.com/en/5.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/5.1/topics/i18n/

LANGUAGE_CODE = 'zh-hans'

TIME_ZONE = 'Asia/Shanghai'

USE_I18N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/5.1/howto/static-files/

STATIC_URL = 'static/'


# Default primary key field type
# https://docs.djangoproject.com/en/5.1/ref/settings/#default-auto-field

DEFAULT_AUTO_FIELD = 'django.db.models.BigAutoField'

# 确保logs文件夹存在
logs_dir = os.path.join(BASE_DIR, 'logs')
if not os.path.exists(logs_dir):
    os.makedirs(logs_dir)

# 日志配置
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '{levelname} {asctime} {module} {message}',
            'style': '{',
        },
        'simple': {
            'format': '{levelname} {message}',
            'style': '{',
        },
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'verbose',
        },
        'file': {
            'class': 'logging.FileHandler',
            'filename': os.path.join(BASE_DIR, 'logs', 'app.log'),
            'formatter': 'verbose',
            'encoding': 'utf-8'
        },
    },
    'loggers': {
        'app': {
            'handlers': ['console', 'file'],
            'level': 'INFO',
            'propagate': True,
        },
        'daren_detail': {
            'handlers': ['console', 'file'],
            'level': 'INFO',
            'propagate': True,
        },
        'brands': {
            'handlers': ['console', 'file'],
            'level': 'INFO',
            'propagate': True,
        },
    },
}

# 自定义用户模型
AUTH_USER_MODEL = 'user.User'

# 媒体文件配置
MEDIA_URL = '/media/'
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')

# REST Framework 设置
REST_FRAMEWORK = {
    'DEFAULT_AUTHENTICATION_CLASSES': [],  # 默认不需要认证
    'DEFAULT_PERMISSION_CLASSES': [],  # 默认不需要权限
    'UNAUTHENTICATED_USER': None
}

# JWT 设置
from datetime import timedelta
SIMPLE_JWT = {
    'ACCESS_TOKEN_LIFETIME': timedelta(days=1),
    'REFRESH_TOKEN_LIFETIME': timedelta(days=7),
    'ROTATE_REFRESH_TOKENS': False,
    'ALGORITHM': 'HS256',
    'SIGNING_KEY': SECRET_KEY,
    'AUTH_HEADER_TYPES': ('Bearer',),
    'USER_ID_FIELD': 'id',
    'USER_ID_CLAIM': 'user_id',
    'UPDATE_LAST_LOGIN': False,  # 不在 token 中记录最后登录时间
    'TOKEN_TYPE_CLAIM': None,    # 不在 token 中包含 token 类型
    'JTI_CLAIM': None,           # 不在 token 中包含 JWT ID
}

API_BASE_URL = 'http://81.69.223.133:48329'
SILICON_CLOUD_API_KEY = 'sk-xqbujijjqqmlmlvkhvxeogqjtzslnhdtqxqgiyuhwpoqcjvf'
GMAIL_WEBHOOK_URL = 'https://7403-180-159-100-165.ngrok-free.app/api/gmail/webhook/'
APPLICATION_ID = 'd5d11efa-ea9a-11ef-9933-0242ac120006'


# 全局代理设置
# 格式为 'http://主机名:端口号'，例如：'http://127.0.0.1:7890'
# 此代理将应用于所有HTTP/HTTPS请求和Gmail API请求
# 如果代理不可用，请将此值设为None或注释掉此行
PROXY_URL = 'http://127.0.0.1:7890'


# Gmail Pub/Sub相关设置
GOOGLE_CLOUD_PROJECT_ID = 'knowledge-454905'
# 主题名称
GMAIL_PUBSUB_TOPIC = 'gmail-watch-topic'

# 设置允许使用Google Pub/Sub的应用列表
INSTALLED_APPS += ['google.cloud.pubsub']

# Celery配置
CELERY_BROKER_URL = 'redis://localhost:6379/0'  # 使用Redis作为消息代理
CELERY_RESULT_BACKEND = 'redis://localhost:6379/0'  # 使用Redis存储任务结果
CELERY_ACCEPT_CONTENT = ['json']  # 指定接受的内容类型
CELERY_TASK_SERIALIZER = 'json'  # 任务序列化和反序列化使用JSON
CELERY_RESULT_SERIALIZER = 'json'  # 结果序列化使用JSON
CELERY_TIMEZONE = 'Asia/Shanghai'  # 使用上海时区
CELERY_TASK_TRACK_STARTED = True  # 追踪任务的开始状态
CELERY_TASK_TIME_LIMIT = 300  # 任务的hard time limit
CELERY_TASK_SOFT_TIME_LIMIT = 240  # 任务的soft time limit
CELERY_WORKER_MAX_TASKS_PER_CHILD = 500  # 工作进程处理多少个任务后重启

# Windows平台Celery特定设置
CELERY_BROKER_CONNECTION_RETRY_ON_STARTUP = True  # 启动时尝试重新连接
CELERY_WORKER_CONCURRENCY = 1  # Windows下使用单进程模式，避免权限错误
CELERY_TASK_ALWAYS_EAGER = False  # 不要在Django主进程中执行任务
CELERY_BROKER_HEARTBEAT = 0  # 禁用心跳检测，解决Windows的问题

FEISHU_APP_ID = "cli_a5c97daacb9e500d"
FEISHU_APP_SECRET = "fdVeOCLXmuIHZVmSV0VbJh9wd0Kq1o5y"
FEISHU_DEFAULT_APP_TOKEN = "XYE6bMQUOaZ5y5svj4vcWohGnmg"
FEISHU_DEFAULT_ACCESS_TOKEN = "u-fK0HvbXVte.G2xzYs5oxV6k1nHu1glvFgG00l0Ma24VD"

